import { LitElement } from 'lit';
declare const UUISliderElement_base: (new (...args: any[]) => import("@umbraco-ui/uui-base/lib/mixins").LabelMixinInterface) & typeof LitElement;
/**
 *  @element uui-slider
 *  @description - Native `<input type="range">` wrapper.
 *  @extends LabelMixin(LitElement)
 *  @slot label - for the input label text.
 *  @fires UUISliderEvent#input on input
 *
 */
export declare class UUISliderElement extends UUISliderElement_base {
    static styles: import("lit").CSSResult[];
    /**
     * This is a static class field indicating that the element is can be used inside a native form and participate in its events. It may require a polyfill, check support here https://developer.mozilla.org/en-US/docs/Web/API/HTMLElement/attachInternals.  Read more about form controls here https://web.dev/more-capable-form-controls/
     * @type {boolean}
     */
    static readonly formAssociated = true;
    private input;
    private track;
    /**
     * Hides the numbers representing the value of each steps. Dots will still be visible
     * @type {boolean}
     * @attr 'hide-step-values'
     * @default false
     */
    hideStepValues: boolean;
    /**
     * This is a minimum value of the input.
     * @type {number}
     * @attr
     * @default 100
     */
    min: number;
    /**
     * This is a maximum value of the input.
     * @type {number}
     * @attr
     * @default 100
     */
    max: number;
    /**
     * This reflects the behavior of a native input step attribute.
     * @type {number}
     * @attr
     * @default 1
     */
    step: number;
    private _value;
    /**
     * This is a value property of the uui-slider.
     * @type {string}
     * @attr
     * @default ''
     */
    get value(): string;
    set value(newVal: string);
    /**
     * Set to true to visually hide the labeling provided by the component. The element will still have label for accessibility purposes
     * @type {boolean}
     * @attr hide-label
     * @default false
     */
    hideLabel: boolean;
    private _internals;
    constructor();
    connectedCallback(): void;
    disconnectedCallback(): void;
    firstUpdated(): void;
    private _updateSteps;
    updated(changedProperties: any): void;
    private stepWidth;
    private _calculateStepWidth;
    private onWindowResize;
    protected steps: number[];
    protected sliderPosition: string;
    protected fillScale: string;
    private _calculateSliderPosition;
    private _thumbDynamicStyles;
    private _onInput;
    private _range;
    render(): import("lit-html").TemplateResult<1>;
}
export {};
